@@ -24,14 +24,14 @@ class SystemdJob : public KJob
     Q_OBJECT
 
 public:
-    SystemdJob(const SYSTEMD::actions &action);
+    SystemdJob(SYSTEMD::actions action);
     ~SystemdJob();
     void start() override;
     QString name();
 
 private:
     void systemdAction(const SYSTEMD::actions value);
-    SYSTEMD::actions m_action;
+    const SYSTEMD::actions m_action;
 };
 
 #endif
